@@ -12,7 +12,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Mapping, Sequence
 
 from .literals import (
     ComponentTypeType,
@@ -188,8 +188,8 @@ AmiDistributionConfigurationTypeDef = TypedDict(
     {
         "name": str,
         "description": str,
-        "targetAccountIds": List[str],
-        "amiTags": Dict[str, str],
+        "targetAccountIds": Sequence[str],
+        "amiTags": Mapping[str, str],
         "kmsKeyId": str,
         "launchPermission": "LaunchPermissionConfigurationTypeDef",
     },
@@ -236,7 +236,7 @@ _RequiredComponentConfigurationTypeDef = TypedDict(
 _OptionalComponentConfigurationTypeDef = TypedDict(
     "_OptionalComponentConfigurationTypeDef",
     {
-        "parameters": List["ComponentParameterTypeDef"],
+        "parameters": Sequence["ComponentParameterTypeDef"],
     },
     total=False,
 )
@@ -275,7 +275,7 @@ ComponentParameterTypeDef = TypedDict(
     "ComponentParameterTypeDef",
     {
         "name": str,
-        "value": List[str],
+        "value": Sequence[str],
     },
 )
 
@@ -345,7 +345,7 @@ _OptionalContainerDistributionConfigurationTypeDef = TypedDict(
     "_OptionalContainerDistributionConfigurationTypeDef",
     {
         "description": str,
-        "containerTags": List[str],
+        "containerTags": Sequence[str],
     },
     total=False,
 )
@@ -420,11 +420,11 @@ _OptionalCreateComponentRequestRequestTypeDef = TypedDict(
     {
         "description": str,
         "changeDescription": str,
-        "supportedOsVersions": List[str],
+        "supportedOsVersions": Sequence[str],
         "data": str,
         "uri": str,
         "kmsKeyId": str,
-        "tags": Dict[str, str],
+        "tags": Mapping[str, str],
     },
     total=False,
 )
@@ -452,7 +452,7 @@ _RequiredCreateContainerRecipeRequestRequestTypeDef = TypedDict(
         "containerType": Literal["DOCKER"],
         "name": str,
         "semanticVersion": str,
-        "components": List["ComponentConfigurationTypeDef"],
+        "components": Sequence["ComponentConfigurationTypeDef"],
         "parentImage": str,
         "targetRepository": "TargetContainerRepositoryTypeDef",
         "clientToken": str,
@@ -467,7 +467,7 @@ _OptionalCreateContainerRecipeRequestRequestTypeDef = TypedDict(
         "dockerfileTemplateUri": str,
         "platformOverride": PlatformType,
         "imageOsVersionOverride": str,
-        "tags": Dict[str, str],
+        "tags": Mapping[str, str],
         "workingDirectory": str,
         "kmsKeyId": str,
     },
@@ -496,7 +496,7 @@ _RequiredCreateDistributionConfigurationRequestRequestTypeDef = TypedDict(
     "_RequiredCreateDistributionConfigurationRequestRequestTypeDef",
     {
         "name": str,
-        "distributions": List["DistributionTypeDef"],
+        "distributions": Sequence["DistributionTypeDef"],
         "clientToken": str,
     },
 )
@@ -504,7 +504,7 @@ _OptionalCreateDistributionConfigurationRequestRequestTypeDef = TypedDict(
     "_OptionalCreateDistributionConfigurationRequestRequestTypeDef",
     {
         "description": str,
-        "tags": Dict[str, str],
+        "tags": Mapping[str, str],
     },
     total=False,
 )
@@ -546,7 +546,7 @@ _OptionalCreateImagePipelineRequestRequestTypeDef = TypedDict(
         "enhancedImageMetadataEnabled": bool,
         "schedule": "ScheduleTypeDef",
         "status": PipelineStatusType,
-        "tags": Dict[str, str],
+        "tags": Mapping[str, str],
     },
     total=False,
 )
@@ -574,7 +574,7 @@ _RequiredCreateImageRecipeRequestRequestTypeDef = TypedDict(
     {
         "name": str,
         "semanticVersion": str,
-        "components": List["ComponentConfigurationTypeDef"],
+        "components": Sequence["ComponentConfigurationTypeDef"],
         "parentImage": str,
         "clientToken": str,
     },
@@ -583,8 +583,8 @@ _OptionalCreateImageRecipeRequestRequestTypeDef = TypedDict(
     "_OptionalCreateImageRecipeRequestRequestTypeDef",
     {
         "description": str,
-        "blockDeviceMappings": List["InstanceBlockDeviceMappingTypeDef"],
-        "tags": Dict[str, str],
+        "blockDeviceMappings": Sequence["InstanceBlockDeviceMappingTypeDef"],
+        "tags": Mapping[str, str],
         "workingDirectory": str,
         "additionalInstanceConfiguration": "AdditionalInstanceConfigurationTypeDef",
     },
@@ -623,7 +623,7 @@ _OptionalCreateImageRequestRequestTypeDef = TypedDict(
         "distributionConfigurationArn": str,
         "imageTestsConfiguration": "ImageTestsConfigurationTypeDef",
         "enhancedImageMetadataEnabled": bool,
-        "tags": Dict[str, str],
+        "tags": Mapping[str, str],
     },
     total=False,
 )
@@ -657,15 +657,15 @@ _OptionalCreateInfrastructureConfigurationRequestRequestTypeDef = TypedDict(
     "_OptionalCreateInfrastructureConfigurationRequestRequestTypeDef",
     {
         "description": str,
-        "instanceTypes": List[str],
-        "securityGroupIds": List[str],
+        "instanceTypes": Sequence[str],
+        "securityGroupIds": Sequence[str],
         "subnetId": str,
         "logging": "LoggingTypeDef",
         "keyPair": str,
         "terminateInstanceOnFailure": bool,
         "snsTopicArn": str,
-        "resourceTags": Dict[str, str],
-        "tags": Dict[str, str],
+        "resourceTags": Mapping[str, str],
+        "tags": Mapping[str, str],
     },
     total=False,
 )
@@ -852,8 +852,8 @@ _OptionalDistributionTypeDef = TypedDict(
     {
         "amiDistributionConfiguration": "AmiDistributionConfigurationTypeDef",
         "containerDistributionConfiguration": "ContainerDistributionConfigurationTypeDef",
-        "licenseConfigurationArns": List[str],
-        "launchTemplateConfigurations": List["LaunchTemplateConfigurationTypeDef"],
+        "licenseConfigurationArns": Sequence[str],
+        "launchTemplateConfigurations": Sequence["LaunchTemplateConfigurationTypeDef"],
     },
     total=False,
 )
@@ -881,7 +881,7 @@ FilterTypeDef = TypedDict(
     "FilterTypeDef",
     {
         "name": str,
-        "values": List[str],
+        "values": Sequence[str],
     },
     total=False,
 )
@@ -1225,7 +1225,7 @@ _OptionalImportComponentRequestRequestTypeDef = TypedDict(
         "data": str,
         "uri": str,
         "kmsKeyId": str,
-        "tags": Dict[str, str],
+        "tags": Mapping[str, str],
     },
     total=False,
 )
@@ -1300,7 +1300,7 @@ InstanceConfigurationTypeDef = TypedDict(
     "InstanceConfigurationTypeDef",
     {
         "image": str,
-        "blockDeviceMappings": List["InstanceBlockDeviceMappingTypeDef"],
+        "blockDeviceMappings": Sequence["InstanceBlockDeviceMappingTypeDef"],
     },
     total=False,
 )
@@ -1308,8 +1308,8 @@ InstanceConfigurationTypeDef = TypedDict(
 LaunchPermissionConfigurationTypeDef = TypedDict(
     "LaunchPermissionConfigurationTypeDef",
     {
-        "userIds": List[str],
-        "userGroups": List[str],
+        "userIds": Sequence[str],
+        "userGroups": Sequence[str],
     },
     total=False,
 )
@@ -1373,7 +1373,7 @@ ListComponentsRequestRequestTypeDef = TypedDict(
     "ListComponentsRequestRequestTypeDef",
     {
         "owner": OwnershipType,
-        "filters": List["FilterTypeDef"],
+        "filters": Sequence["FilterTypeDef"],
         "byName": bool,
         "maxResults": int,
         "nextToken": str,
@@ -1395,7 +1395,7 @@ ListContainerRecipesRequestRequestTypeDef = TypedDict(
     "ListContainerRecipesRequestRequestTypeDef",
     {
         "owner": OwnershipType,
-        "filters": List["FilterTypeDef"],
+        "filters": Sequence["FilterTypeDef"],
         "maxResults": int,
         "nextToken": str,
     },
@@ -1415,7 +1415,7 @@ ListContainerRecipesResponseTypeDef = TypedDict(
 ListDistributionConfigurationsRequestRequestTypeDef = TypedDict(
     "ListDistributionConfigurationsRequestRequestTypeDef",
     {
-        "filters": List["FilterTypeDef"],
+        "filters": Sequence["FilterTypeDef"],
         "maxResults": int,
         "nextToken": str,
     },
@@ -1441,7 +1441,7 @@ _RequiredListImageBuildVersionsRequestRequestTypeDef = TypedDict(
 _OptionalListImageBuildVersionsRequestRequestTypeDef = TypedDict(
     "_OptionalListImageBuildVersionsRequestRequestTypeDef",
     {
-        "filters": List["FilterTypeDef"],
+        "filters": Sequence["FilterTypeDef"],
         "maxResults": int,
         "nextToken": str,
     },
@@ -1507,7 +1507,7 @@ _RequiredListImagePipelineImagesRequestRequestTypeDef = TypedDict(
 _OptionalListImagePipelineImagesRequestRequestTypeDef = TypedDict(
     "_OptionalListImagePipelineImagesRequestRequestTypeDef",
     {
-        "filters": List["FilterTypeDef"],
+        "filters": Sequence["FilterTypeDef"],
         "maxResults": int,
         "nextToken": str,
     },
@@ -1535,7 +1535,7 @@ ListImagePipelineImagesResponseTypeDef = TypedDict(
 ListImagePipelinesRequestRequestTypeDef = TypedDict(
     "ListImagePipelinesRequestRequestTypeDef",
     {
-        "filters": List["FilterTypeDef"],
+        "filters": Sequence["FilterTypeDef"],
         "maxResults": int,
         "nextToken": str,
     },
@@ -1556,7 +1556,7 @@ ListImageRecipesRequestRequestTypeDef = TypedDict(
     "ListImageRecipesRequestRequestTypeDef",
     {
         "owner": OwnershipType,
-        "filters": List["FilterTypeDef"],
+        "filters": Sequence["FilterTypeDef"],
         "maxResults": int,
         "nextToken": str,
     },
@@ -1577,7 +1577,7 @@ ListImagesRequestRequestTypeDef = TypedDict(
     "ListImagesRequestRequestTypeDef",
     {
         "owner": OwnershipType,
-        "filters": List["FilterTypeDef"],
+        "filters": Sequence["FilterTypeDef"],
         "byName": bool,
         "maxResults": int,
         "nextToken": str,
@@ -1599,7 +1599,7 @@ ListImagesResponseTypeDef = TypedDict(
 ListInfrastructureConfigurationsRequestRequestTypeDef = TypedDict(
     "ListInfrastructureConfigurationsRequestRequestTypeDef",
     {
-        "filters": List["FilterTypeDef"],
+        "filters": Sequence["FilterTypeDef"],
         "maxResults": int,
         "nextToken": str,
     },
@@ -1776,7 +1776,7 @@ TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
-        "tags": Dict[str, str],
+        "tags": Mapping[str, str],
     },
 )
 
@@ -1792,7 +1792,7 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
         "resourceArn": str,
-        "tagKeys": List[str],
+        "tagKeys": Sequence[str],
     },
 )
 
@@ -1800,7 +1800,7 @@ _RequiredUpdateDistributionConfigurationRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateDistributionConfigurationRequestRequestTypeDef",
     {
         "distributionConfigurationArn": str,
-        "distributions": List["DistributionTypeDef"],
+        "distributions": Sequence["DistributionTypeDef"],
         "clientToken": str,
     },
 )
@@ -1883,14 +1883,14 @@ _OptionalUpdateInfrastructureConfigurationRequestRequestTypeDef = TypedDict(
     "_OptionalUpdateInfrastructureConfigurationRequestRequestTypeDef",
     {
         "description": str,
-        "instanceTypes": List[str],
-        "securityGroupIds": List[str],
+        "instanceTypes": Sequence[str],
+        "securityGroupIds": Sequence[str],
         "subnetId": str,
         "logging": "LoggingTypeDef",
         "keyPair": str,
         "terminateInstanceOnFailure": bool,
         "snsTopicArn": str,
-        "resourceTags": Dict[str, str],
+        "resourceTags": Mapping[str, str],
     },
     total=False,
 )
